# MoneySuffixes Step By Step

1. Install MoneySuffixes
```bash
pip install moneysuffixes
```

2. Run Code
```python
from moneysuffixes import shorten

print(shorten(100000))
# Output: 100K
```

3. Done!